==> TRONCO_2.4.3.tar.gz: TRONCO/inst/NEWS.Rd <==
\name{NEWS}
\title{News for the package \pkg{TRONCO}}
\encoding{UTF-8}

\section{Changes in Version 2.4.3}{
    \itemize{
        \item New algorithms: Prim, Chow-Liu, Prim and Edmonds.
        \item New scores: PMI, CPMI, MI
        \item A better bootstrap implementation
    }
}

\section{Changes in Version 2.4.2}{
    \itemize{
        \item Implementation of a noise model plus maximum spanning tree algorithms.
    }
}

\section{Changes in Version 2.4.1}{
    \itemize{
        \item A better implementation of remove.cycles.
    }
}

\section{Changes in Version 2.4.0}{
    \itemize{
        \item New statistics available for model confidence via
        cross-validation routines. New algorithms based on Minimum
        Spanning Tree extraction.
    }
}

\section{Changes in Version 2.0.0}{
    \itemize{
        \item Released in summer 2015 on our GitHUB, will replace the 
        Bioconductor version in autumn 2015. This version is parallel,
        includes also the CAPRI algorithm, supports common input formats
        such as GISTIC (for Copy Number Variants), MAF (for mutations' annotation),
        supports TCGA samples editing and queries to the CBio portal.
        This version comes with new plotting capabilities, and a general
        from-scratch design. It is not compatible with previous releases.
    }
}

\section{Changes in Version 1.0.0}{
    \itemize{
        \item Released in mid 2014 includes CAPRESE algorithm.
        It is now outdated and no more maintained. 
    }
}

==> TRONCO_2.6.1.tar.gz: TRONCO/inst/NEWS.Rd <==
\name{NEWS}
\title{News for the package \pkg{TRONCO}}
\encoding{UTF-8}

\section{Changes in Version 2.4.3}{
    \itemize{
        \item New algorithms: Edmonds, Gabow, Chow-Liu and Prim.
        \item New scores: PMI, CPMI, MI
        \item A better bootstrap implementation
    }
}

\section{Changes in Version 2.4.2}{
    \itemize{
        \item Implementation of maximum spanning tree algorithms.
        \item Implementation of a noise model for cumulative phenomena.
    }
}

\section{Changes in Version 2.4.1}{
    \itemize{
        \item A better implementation of remove.cycles.
    }
}

\section{Changes in Version 2.4.0}{
    \itemize{
        \item New statistics available for model confidence via
        cross-validation routines. New algorithms based on Minimum
        Spanning Tree extraction.
    }
}

\section{Changes in Version 2.0.0}{
    \itemize{
        \item Released in summer 2015 on our GitHUB, will replace the 
        Bioconductor version in autumn 2015. This version is parallel,
        includes also the CAPRI algorithm, supports common input formats
        such as GISTIC (for Copy Number Variants), MAF (for mutations' annotation),
        supports TCGA samples editing and queries to the CBio portal.
        This version comes with new plotting capabilities, and a general
        from-scratch design. It is not compatible with previous releases.
    }
}

\section{Changes in Version 1.0.0}{
    \itemize{
        \item Released in mid 2014 includes CAPRESE algorithm.
        It is now outdated and no more maintained. 
    }
}
